summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_cookie.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_cookie.py')
-rw-r--r--Lib/test/test_cookie.py114
1 files changed, 73 insertions, 41 deletions
diff --git a/Lib/test/test_cookie.py b/Lib/test/test_cookie.py
index c20beee..e7c0cf1 100644
--- a/Lib/test/test_cookie.py
+++ b/Lib/test/test_cookie.py
@@ -1,6 +1,7 @@
# Simple test suite for Cookie.py
-from test.test_support import verify, verbose, run_doctest
+from test.test_support import run_unittest, run_doctest
+import unittest
import Cookie
import warnings
@@ -8,43 +9,74 @@ warnings.filterwarnings("ignore",
".* class is insecure.*",
DeprecationWarning)
-# Currently this only tests SimpleCookie
-
-cases = [
- ('chips=ahoy; vienna=finger', {'chips':'ahoy', 'vienna':'finger'}),
- ('keebler="E=mc2; L=\\"Loves\\"; fudge=\\012;"',
- {'keebler' : 'E=mc2; L="Loves"; fudge=\012;'}),
-
- # Check illegal cookies that have an '=' char in an unquoted value
- ('keebler=E=mc2', {'keebler' : 'E=mc2'})
- ]
-
-for data, dict in cases:
- C = Cookie.SimpleCookie() ; C.load(data)
- print repr(C)
- print C.output(sep='\n')
- for k, v in sorted(dict.iteritems()):
- print ' ', k, repr( C[k].value ), repr(v)
- verify(C[k].value == v)
- print C[k]
-
-C = Cookie.SimpleCookie()
-C.load('Customer="WILE_E_COYOTE"; Version=1; Path=/acme')
-
-verify(C['Customer'].value == 'WILE_E_COYOTE')
-verify(C['Customer']['version'] == '1')
-verify(C['Customer']['path'] == '/acme')
-
-print C.output(['path'])
-print C.js_output()
-print C.js_output(['path'])
-
-# Try cookie with quoted meta-data
-C = Cookie.SimpleCookie()
-C.load('Customer="WILE_E_COYOTE"; Version="1"; Path="/acme"')
-verify(C['Customer'].value == 'WILE_E_COYOTE')
-verify(C['Customer']['version'] == '1')
-verify(C['Customer']['path'] == '/acme')
-
-print "If anything blows up after this line, it's from Cookie's doctest."
-run_doctest(Cookie)
+class CookieTests(unittest.TestCase):
+ # Currently this only tests SimpleCookie
+ def test_basic(self):
+ cases = [
+ { 'data': 'chips=ahoy; vienna=finger',
+ 'dict': {'chips':'ahoy', 'vienna':'finger'},
+ 'repr': "<SimpleCookie: chips='ahoy' vienna='finger'>",
+ 'output': 'Set-Cookie: chips=ahoy\nSet-Cookie: vienna=finger',
+ },
+
+ { 'data': 'keebler="E=mc2; L=\\"Loves\\"; fudge=\\012;"',
+ 'dict': {'keebler' : 'E=mc2; L="Loves"; fudge=\012;'},
+ 'repr': '''<SimpleCookie: keebler='E=mc2; L="Loves"; fudge=\\n;'>''',
+ 'output': 'Set-Cookie: keebler="E=mc2; L=\\"Loves\\"; fudge=\\012;"',
+ },
+
+ # Check illegal cookies that have an '=' char in an unquoted value
+ { 'data': 'keebler=E=mc2',
+ 'dict': {'keebler' : 'E=mc2'},
+ 'repr': "<SimpleCookie: keebler='E=mc2'>",
+ 'output': 'Set-Cookie: keebler=E=mc2',
+ }
+ ]
+
+ for case in cases:
+ C = Cookie.SimpleCookie()
+ C.load(case['data'])
+ self.assertEqual(repr(C), case['repr'])
+ self.assertEqual(C.output(sep='\n'), case['output'])
+ for k, v in sorted(case['dict'].iteritems()):
+ self.assertEqual(C[k].value, v)
+
+ def test_load(self):
+ C = Cookie.SimpleCookie()
+ C.load('Customer="WILE_E_COYOTE"; Version=1; Path=/acme')
+
+ self.assertEqual(C['Customer'].value, 'WILE_E_COYOTE')
+ self.assertEqual(C['Customer']['version'], '1')
+ self.assertEqual(C['Customer']['path'], '/acme')
+
+ self.assertEqual(C.output(['path']),
+ 'Set-Cookie: Customer="WILE_E_COYOTE"; Path=/acme')
+ self.assertEqual(C.js_output(), """
+ <script type="text/javascript">
+ <!-- begin hiding
+ document.cookie = "Customer="WILE_E_COYOTE"; Path=/acme; Version=1";
+ // end hiding -->
+ </script>
+ """)
+ self.assertEqual(C.js_output(['path']), """
+ <script type="text/javascript">
+ <!-- begin hiding
+ document.cookie = "Customer="WILE_E_COYOTE"; Path=/acme";
+ // end hiding -->
+ </script>
+ """)
+
+ def test_quoted_meta(self):
+ # Try cookie with quoted meta-data
+ C = Cookie.SimpleCookie()
+ C.load('Customer="WILE_E_COYOTE"; Version="1"; Path="/acme"')
+ self.assertEqual(C['Customer'].value, 'WILE_E_COYOTE')
+ self.assertEqual(C['Customer']['version'], '1')
+ self.assertEqual(C['Customer']['path'], '/acme')
+
+def test_main():
+ run_unittest(CookieTests)
+ run_doctest(Cookie)
+
+if __name__ == '__main__':
+ test_main()